@@ -13,6 +13,7 @@ from steam_sdk.drivers.DriverFiQuS import DriverFiQuS
 from steam_sdk.drivers.DriverLEDET import DriverLEDET
 from steam_sdk.drivers.DriverPSPICE import DriverPSPICE
 from steam_sdk.drivers.DriverPyBBQ import DriverPyBBQ
+from steam_sdk.parsers.ParserYAML import dict_to_yaml
 from steam_sdk.utils.make_folder_if_not_existing import make_folder_if_not_existing
 from steam_sdk.utils.rgetattr import rgetattr
 from steam_sdk.utils.sgetattr import rsetattr
@@ -168,6 +169,24 @@ class AnalysisSTEAM:
             yaml.dump(dictonary_settings, yaml_file, default_flow_style=False, sort_keys=False)
         if verbose: print('File {} was saved locally.'.format(path_temp_file_settings))
 
+    def write_analysis_file(self, path_output_file: str):
+        '''
+        ** Write the analysis data in the target file **
+        This can be helpful to keep track of the final state of the DataAnalysis object before running it, especially if it was modified programmatically.
+        :param path_output_file: string to the file to write
+        :return: None
+        '''
+
+        verbose = self.verbose
+
+        # Make sure the target folder exists
+        make_folder_if_not_existing(os.path.dirname(path_output_file), verbose=verbose)
+
+        # Write the STEAM analysis data to a yaml file
+        all_data_dict = {**self.data_analysis.dict()}
+        dict_to_yaml(all_data_dict, path_output_file, list_exceptions=['AnalysisStepSequence', 'variables_to_change'])
+        if verbose: print(f'File {path_output_file} saved.')
+
     def run_analysis(self, verbose: bool = None):
         """
             ** Run the analysis **
