@@ -1,7 +1,7 @@
 from pydantic import BaseModel
 
 
-class DataSettingsSTEAM(BaseModel):
+class DataSettings(BaseModel):
     """
         Dataclass of settings for STEAM analyses
         This will be populated either form a local settings file (if flag_permanent_settings=False)
