@@ -13,7 +13,7 @@ from steam_sdk.builders.BuilderLEDET import BuilderLEDET
 from steam_sdk.data.TemplateLEDET import get_template_LEDET_inputs_sheet, get_template_LEDET_options_sheet, get_template_LEDET_plots_sheet, get_template_LEDET_variables_sheet
 from steam_sdk.parsers import ParserMap2d
 from steam_sdk.parsers.ParserExcel import read_row, compare_two_parameters, write2Excel
-from steam_sdk.parsers.dict_to_yaml import dict_to_yaml
+from steam_sdk.parsers.ParserYAML import dict_to_yaml
 from steam_sdk.utils.NumpyEncoder import NumpyEncoder
 
 
