@@ -3,7 +3,7 @@ import numpy as np
 import yaml
 
 
-def data_class_from_yaml(full_file_path, data_class):
+def yaml_to_data_class(full_file_path, data_class):
     with open(full_file_path, 'r') as stream:
         yaml = ruamel.yaml.YAML(typ='safe', pure=True)
         yaml_str = yaml.load(stream)
