@@ -10,6 +10,7 @@ from steam_sdk.data.DataSignal import DataSignal
 
 from steam_sdk.parsers.ParserMat import get_signals_from_mat
 from steam_sdk.parsers.ParserCsv import get_signals_from_csv
+from steam_sdk.parsers.ParserCsd import get_signals_from_csd
 from steam_sdk.parsers.ParserTdms import ParserTdms
 from steam_sdk.utils.make_folder_if_not_existing import make_folder_if_not_existing
 from steam_sdk.utils.unique import unique
@@ -272,6 +273,8 @@ class Viewer:
                     df_sim_data = get_signals_from_csv(full_path_sim_file, signal_list_sim)
                 elif file_type == 'mat':
                     df_sim_data = get_signals_from_mat(full_path_sim_file, signal_list_sim)
+                elif file_type == 'csd':
+                    df_sim_data = get_signals_from_csd(full_path_sim_file, signal_list_sim)
                 else:
                     raise Exception(f'File type {file_type} not supported.')
             else:
@@ -317,7 +320,7 @@ class Viewer:
 
 
                 # Plot current signal (meas, or sim, or both) of the current event
-                path_output_figures = dict_events['path_output_figures'][t-1]
+                path_output_figures = Path(dict_events['path_output_figures'][t-1]).resolve()
                 if self.flag_save_figures:
                     fig_name    = signal.name
                     figure_name = f'{event_label}_{fig_name}.png'
